# ifndef yyFinalCode
# define yyFinalCode

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* FinalCode_Exit) ARGS ((void));

extern void FinalCode ARGS ((tTree t));

extern void BeginFinalCode ARGS ((void));
extern void CloseFinalCode ARGS ((void));

# endif
